@@ -12,6 +12,8 @@ class NumerousJob:
         self.hibernate_event = self._client.hibernate_event
         self.terminate_event = self._client.terminate_event
 
+        self.action = 'continue'
+
         self._exception = None
         self._return_value = None
 
@@ -25,12 +27,14 @@ class NumerousJob:
     def _event_watch(self):
         while not self._terminate:
             if self.hibernate_event.is_set():
+                self.action = 'hibernate'
                 self.payload_thread.join(self._timeout)
                 if self.payload_thread.is_alive():
                     self.payload_thread.kill()
                 break
 
             if self.terminate_event.is_set():
+                self.action = 'terminate'
                 self.payload_thread.join(self._timeout)
                 if self.payload_thread.is_alive():
                     self.payload_thread.kill()
