@@ -1,4 +1,4 @@
-import json
+import json, os
 from numerous_image_tools.image_test.build import build_image
 from numerous_image_tools.image_test.run import run_container
 
@@ -26,6 +26,12 @@ def read_numerous_environment(config_folder):
 
     return config
 
+def read_set_numerous_environment(config_folder):
+    environment = read_numerous_environment(config_folder)
+    for k,v in environment.items():
+        os.environ[k] = v
+    return environment
+
 def build_run_numerous_image(docker_context_folder=".", numerous_config_folder="."):
     environment = read_numerous_environment(numerous_config_folder)
     image_id = build_image(docker_context_folder)
