@@ -69,18 +69,26 @@ class Component:
         return get_item_from_list(self.parameters, value, key)
 
 
+class Job:
+    def __init__(self, _id):
+        self._id = _id
+
 def dummy_get_config(config):
     return {}
 
 class Scenario:
     def __init__(self, config_source=dummy_get_config):
         self.components={}
+        self.jobs = {}
         self.instanciated_components={}
         self._config = config_source
 
     def add_component(self, component:Component):
         self.components[component._id] = component
 
+    def add_job(self, job:Job):
+        self.jobs[job._id] = job
+
     def get_component(self, value, key='_id'):
         return get_item_from_list(self.components, value, key)
 
@@ -159,4 +167,9 @@ def scenario_from_dict(scenario_dict, config_source=dummy_get_config):
 
         scenario.add_component(component)
 
+    for job_id, job_data in scenario_dict['jobs'].items():
+        job = Job(_id=job_id)
+        map_basic_attributes(job, job_data, allow_list=True, allow_dict=True)
+        scenario.add_job(job)
+
     return scenario
\ No newline at end of file
